# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gata']

package_data = \
{'': ['*']}

install_requires = \
['typing_extensions>=3.7.4,<4.0.0']

setup_kwargs = {
    'name': 'gata',
    'version': '3.3.2',
    'description': 'Gata is data validation and transformation library for python',
    'long_description': '# Gata\n![CI](https://github.com/kodemore/gata/workflows/Linting%20and%20Tests/badge.svg?branch=master)\n[![Coverage](https://codecov.io/gh/kodemore/gata/branch/master/graph/badge.svg)](https://codecov.io/gh/kodemore/gata)\n[![Maintainability](https://api.codeclimate.com/v1/badges/00892e0c37a7f1716bdd/maintainability)](https://codeclimate.com/github/kodemore/gata/maintainability)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\nGata is a toolbox library for python\'s dataclasses which allows to serialise/deserialise/validate complex dataclasses.\n\n## Installation\n\n`pip install gata`\n\n## Features\n - non-intrusive interface\n - dataclasses validation mechanism\n - support for complex datatypes\n - serialisation/deserialisation mechanism\n - easy to use field mapping\n - Full IDE support with `Dataclass` class\n\n\n## Example\n```python\nfrom typing import List\nfrom gata import Dataclass\n\n\nclass Pet(Dataclass, frozen=True):\n    tags: List[str]\n    name: str = "Boo"\n    age: int = 0\n\n\ntry:\n    pet = Pet()\nexcept ValueError:\n    pass  # tags are required and undefined, so error will be thrown\n\n\npet = Pet(**{"tags": ["dog"]})\n\nassert pet.serialise() == {\'tags\': [\'dog\'], \'name\': \'Boo\', \'age\': 0}  # serialise object\n\n# exclude `age` field from serialisation, and rename `name` field to `pet_name`\nassert pet.serialise(age=False, name="pet_name") == {\'tags\': [\'dog\'], \'pet_name\': \'Boo\'}\n```\n\n## Non intrusive example\n```python\nfrom typing import List\nfrom gata import validate_dataclass, asdict\nfrom dataclasses import dataclass\n\n\n@dataclass\nclass Pet:\n    tags: List[str]\n    name: str = "Boo"\n    age: int = 0\n\n\ntry:\n    pet = Pet()\n    validate_dataclass(pet)\nexcept ValueError:\n    pass  # tags are required and undefined, so error will be thrown\n\n\npet = Pet(**{"tags": ["dog"]})\n\nassert asdict(pet) == {\'tags\': [\'dog\'], \'name\': \'Boo\', \'age\': 0}  # serialise object\n\n# exclude `age` field from serialisation, and rename `name` field to `pet_name`\nassert asdict(pet, {"age": False, "name": "pet_name"}) == {\'tags\': [\'dog\'], \'pet_name\': \'Boo\'}\n```\n\n> More examples are available under [examples](examples) directory\n\n## Documentation\n\n### [ Introduction](docs/1_introduction.md)\n\n### [ Defining dataclass](docs/2_defining_dataclass.md)\n\n### [ Field types](docs/3_field_types.md)\n\n  * [ Supported standard library types](docs/3_field_types.md#supported-standard-library-types)\n    * [ Primitive types](docs/3_field_types.md#primitive-types)\n    * [ Date-related types](docs/3_field_types.md#date-related-types)\n    * [ Other standard library types](docs/3_field_types.md#other-standard-library-types)\n    * [ Typing library](docs/3_field_types.md#typing-library)\n    * [ Dataclasses](docs/3_field_types.md#dataclasses)\n  * [ Defining custom types](docs/3_field_types.md#defining-custom-types)\n### [ Validation](docs/4_validation.md)\n\n  * [ Automatic validation](docs/4_validation.md#automatic-validation)\n    * [ Performing post initialisation processing](docs/4_validation.md#performing-post-initialisation-processing)\n  * [ Extra validators](docs/4_validation.md#extra-validators)\n### [ Deserialisation](docs/5_deserialisation.md)\n\n  * [ Automatic deserialisation](docs/5_deserialisation.md#automatic-deserialisation)\n  * [ Manual deserialisation](docs/5_deserialisation.md#manual-deserialisation)\n  * [ Nested deserialisation](docs/5_deserialisation.md#nested-deserialisation)\n### [ Serialisation](docs/6_serialisation.md)\n\n  * [ Serialising gata\'s dataclasses](docs/6_serialisation.md#serialising-gatas-dataclasses)\n  * [ Serialising python\'s dataclasses](docs/6_serialisation.md#serialising-pythons-dataclasses)\n  * [ Mapping fields](docs/6_serialisation.md#mapping-fields)\n* [ Turn off validation during instantiation](docs/6_serialisation.md#turn-off-validation-during-instantiation)\n    * [ Nested mapping](docs/6_serialisation.md#nested-mapping)\n### [ Detailed schema](docs/7_detailed_schemas.md)\n  * [ `gata.Field` properties](docs/7_detailed_schemas.md#gatafield-properties)\n    * [ Custom serialisers/deserialisers](docs/7_detailed_schemas.md#custom-serialisersdeserialisers)\n',
    'author': 'dkraczkowski',
    'author_email': 'dawid.kraczkowski@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
